<?php

namespace SGalinski\TypoScriptReferenceFrontend\Service;

use TYPO3\Flow\Annotations as Flow;

/**
 * The Class TsrefRestService contains methods for communication with TypoScript REST API.
 *
 * @package SGalinski\TypoScriptReferenceFrontend\Service
 * @Flow\Scope("singleton")
 */
class TsrefRestService {
	/**
	 * URL of REST API resource.
	 */
	const REST_API_BASE_URL = '127.0.0.1:8000/api/attributes';

	/**
	 * Constant used in $typo3Group field.
	 */
	const NORMAL_GROUP = 1;

	/**
	 * Constant used in $typo3Group field.
	 */
	const PAGE_GROUP = 2;

	/**
	 * Constant used in $typo3Group field.
	 */
	const USER_GROUP = 3;

	/**
	 * Default typo3 version of typoScript attributes
	 */
	const TYPO3_DEFAULT_VERSION = '6.2';

	/**
	 * @param boolean|null $isType
	 * @param string $typo3Version
	 * @param int $typo3Group
	 * @return mixed
	 */
	public function getAttributesJson(
		$isType = NULL, $typo3Version = self::TYPO3_DEFAULT_VERSION, $typo3Group = self::NORMAL_GROUP
	) {
		$curlHandle = $this->initialiseCurl();

		$headerProperties = [
			'version: ' . $typo3Version,
			'typo3group: ' . $typo3Group
		];

		if ($isType !== NULL) {
			$headerProperties[] = 'istype: ' . ($isType ? '1' : '0');
		}

		curl_setopt($curlHandle, CURLOPT_HTTPHEADER, $headerProperties);

		// Download the given URL, and return output
		$output = curl_exec($curlHandle);

		// Close the cURL resource, and free system resources
		curl_close($curlHandle);

		return $output;
	}

	/**
	 * @return resource
	 */
	protected function initialiseCurl() {
		// is cURL installed yet?
		if (!function_exists('curl_init')) {
			throw new \RuntimeException('Sorry cURL is not installed. Install cURL.');
		}

		$curlHandle = curl_init();

		// Set URL to download
		curl_setopt($curlHandle, CURLOPT_URL, self::REST_API_BASE_URL);

		// Should cURL return or print out the data? (true = return, false = print)
		curl_setopt($curlHandle, CURLOPT_RETURNTRANSFER, TRUE);

		// Timeout in seconds
		curl_setopt($curlHandle, CURLOPT_TIMEOUT, 10);
		return $curlHandle;
	}
}